@@ -1,26 +1,47 @@
 import nonebot
 from nonebot import require, get_plugin_config
+from nonebot.rule import Rule
+from nonebot.log import logger
+from nonebot.plugin import PluginMetadata
+
 require("nonebot_plugin_alconna")
 require("nonebot_plugin_htmlrender")
-from openai import AsyncOpenAI
 from arclet.alconna import Args, Option, Alconna, MultiVar
-from nonebot.plugin import PluginMetadata
-from nonebot_plugin_htmlrender import md_to_pic
 from nonebot_plugin_alconna import UniMessage, on_alconna, Match
+from nonebot_plugin_htmlrender import md_to_pic
+
 from .config import Config
+from .GPT_handler import GPTHandler
+from .context_manager import ContextManager
+
 
 plugin_config = get_plugin_config(Config)
-TOKEN = plugin_config.github_token
-MODEL_NAME = plugin_config.ai_model_name
 REPLY_IMAGE = plugin_config.ai_reply_image
-MAX_CONTEXT_LENGTH = plugin_config.max_context_length
 
-endpoint = "https://models.inference.ai.azure.com"
-client = AsyncOpenAI(
-    base_url=endpoint,
-    api_key=TOKEN,
-)
-shared_context = []
+
+if not plugin_config.github_token:
+    logger.opt(colors=True).warning("<yellow>缺失必要配置项 'github_token'，已禁用该插件</yellow>")
+    GPT_handler = None
+else:
+    GPT_handler = GPTHandler(
+        api_key=plugin_config.github_token,
+        endpoint="https://models.inference.ai.azure.com",
+        model_name=plugin_config.ai_model_name,
+        max_context_length=plugin_config.max_context_length,
+        temperature=plugin_config.ai_temperature,
+        max_tokens=plugin_config.ai_max_tokens,
+        top_p=plugin_config.ai_top_p,
+    )
+
+
+def is_enable() -> Rule:
+    def _rule() -> bool:
+        return bool(plugin_config.github_token)
+    return Rule(_rule)
+
+
+context_manager = ContextManager(max_context_length=plugin_config.max_context_length)
+
 
 ai = on_alconna(
     Alconna(
@@ -29,17 +50,19 @@ ai = on_alconna(
         Option("-r|--reset"),
         Option("-i|--image"),
     ),
+    rule=is_enable(),
     use_cmd_start=True,
     block=True,
     aliases={"ai"},
 )
 
+
 @ai.assign("reset")
 async def ai_reset():
-    global shared_context
-    shared_context = []
+    context_manager.reset_context()
     await ai.finish("上下文已重置")
 
+
 @ai.assign("image")
 async def ai_image(user_input: Match[tuple[str]]):
     if user_input.available:
@@ -47,40 +70,22 @@ async def ai_image(user_input: Match[tuple[str]]):
         REPLY_IMAGE = True
         ai.set_path_arg("user_input", " ".join(user_input.result))
 
+
 @ai.handle()
 async def handle_function(user_input: Match[tuple[str]]):
     if user_input.available:
         ai.set_path_arg("user_input", " ".join(user_input.result))
 
+
 @ai.got_path("user_input", prompt="请输入有效问题")
 async def got_location(user_input: str):
-    global shared_context, REPLY_IMAGE
-    if MAX_CONTEXT_LENGTH > 0:
-        shared_context.append({"role": "user", "content": user_input})
-        if len(shared_context) > MAX_CONTEXT_LENGTH:
-            shared_context = shared_context[-MAX_CONTEXT_LENGTH:]
-
-    messages = [
-        {"role": "system", "content": "回答尽量简练,请始终用中文回答"}
-    ]
-    if MAX_CONTEXT_LENGTH > 0:
-        messages += shared_context
-    else:
-        messages.append({"role": "user", "content": user_input})
-
+    global REPLY_IMAGE
     try:
-        response = await client.chat.completions.create(
-        messages=messages,
-        model=MODEL_NAME,
-        temperature=1,
-        max_tokens=500,
-        top_p=1,
-    )
-
-        reply = response.choices[0].message.content
-        if MAX_CONTEXT_LENGTH > 0:
-            shared_context.append({"role": "assistant", "content": reply})
-
+        messages = [{"role": "system", "content": "回答尽量简练,请始终用中文回答"}]
+        context_manager.add_message("user", user_input)
+        messages += context_manager.get_context()
+        reply = await GPT_handler.get_response(messages)
+        context_manager.add_message("assistant", reply)
         if REPLY_IMAGE:
             pic = await md_to_pic(md=reply)
             await UniMessage.image(raw=pic).send(reply_to=True)
@@ -89,6 +94,7 @@ async def got_location(user_input: str):
     finally:
         REPLY_IMAGE = plugin_config.ai_reply_image
 
+
 __plugin_meta__ = PluginMetadata(
     name="githubmodels",
     description="API 调用 GitHub Models 的大语言模型",
@@ -96,4 +102,4 @@ __plugin_meta__ = PluginMetadata(
     type="application",
     homepage="https://github.com/lyqgzbl/nonebot-plugin-githubmodels",
     supported_adapters=None,
-)
+)
\ No newline at end of file
